@@ -25,7 +25,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.12';
+our $VERSION = '0.14';
 sudoku();
 # Preloaded methods go here.
 
@@ -69,8 +69,8 @@ if ($skin == 1) {
 # frame1                            |frame3 frame31       |
 # frame2                            |----------------------
 # frame4                            |frame32   |34frame35 |
-#                                   |frame33   | |        |
-#                                   |          | |        |
+#                                   |frame33   | |frame37 |
+#                                   |frame38   | |        |
 #                                   |          | |        |
 #                                   |          | |        |
 #-----------------------------------|          | |        | 
@@ -142,6 +142,8 @@ if ($skin == 1) {
         my $frame35 = $frame32->Frame(-background => $couleurfond)->pack(-side => 'left');
         my $canvas3 = $frame34->Canvas('-width' => 5, '-height' => 500, -background => 'black')->pack();
         my $frame36 = $frame32->Frame(-height => 3, -background => $couleurfond)->pack();
+        my $frame37 = $frame32->Frame(-background => $couleurfond)->pack(-side => 'left');
+        my $frame38 = $frame32->Frame(-background => $couleurfond)->pack(-side => 'left');
 
 # Left column  -------------------------------
 
@@ -158,7 +160,7 @@ if ($skin == 1) {
         my $balloon12 = $rbutton12->Balloon();
         $balloon12->attach($rbutton12, -msg => tr1("Crer une grille soi mme"));
         $frame33->Photo('imagechiffres', -file => $pref . '/photos/button/' . $langue . '/chiffres.bmp');
-        if ($dessin eq "animaux") {
+        if ($dessin ne "chiffres") {
                 $rbutton13 = $frame33->Button(-command => [sub{$dessin = "chiffres"}],
                         #-text => "Rsoudre avec\ndes chiffres")->pack();
                         -image => "imagechiffres")->pack();
@@ -169,6 +171,18 @@ if ($skin == 1) {
         }
         my $balloon13 = $rbutton13->Balloon();
         $balloon13->attach($rbutton13, -msg => tr1("Il y a des chiffres\n dans les cases"));
+        $frame38->Photo('imagecouleurs', -file => $pref . '/photos/button/' . $langue . '/couleurs.bmp');
+        if ($dessin ne "couleurs") {
+                $rbutton21 = $frame33->Button(-command => [sub{$dessin = "couleurs"}],
+                        #-text => "Rsoudre avec\ndes lettres")->pack();
+                        -image => "imagecouleurs")->pack();
+        } else {
+                $rbutton21 = $frame33->Label(
+                        #-text => "Rsoudre avec\ndes lettres")->pack();
+                        -image => "imagecouleurs")->pack();
+        }
+        my $balloon21 = $rbutton21->Balloon();
+        $balloon21->attach($rbutton21, -msg => tr1("Il y a des couleurs\n dans les cases"));
         my $Label5 = $frame33->Label(-text => tr1('Langues'),
                 -font => "Nimbus 20",
                 -background => $couleurfond,
@@ -224,7 +238,7 @@ if ($skin == 1) {
         my $button18 = $frame35->Label(-text => ' ', -background => $couleurfond,
                 -height => 4, -width => 10)->pack;
         if ($dessin ne "animaux") {
-                $rbutton19 = $frame35->Button(-command => [sub{$dessin = "animaux"}],
+                $rbutton19 = $frame35->Button(-command => [sub{$dessin = "animaux"}], 
                         #-text => "Rsoudre avec\ndes animaux")->pack();
                         -image => "imageanimaux")->pack();
         } else {
@@ -234,46 +248,60 @@ if ($skin == 1) {
         }
         my $balloon19 = $rbutton19->Balloon();
         $balloon19->attach($rbutton19, -msg => tr1("Il y a des animaux\n dans les cases"));
+        $frame37->Photo('imagelettres', -file => $pref . '/photos/button/' . $langue . '/lettres.bmp');
+        if ($dessin ne "lettres") {
+                $rbutton20 = $frame35->Button(-command => [sub{$dessin = "lettres"}],
+                        #-text => "Rsoudre avec\ndes lettres")->pack();
+                        -image => "imagelettres")->pack();
+        } else {
+                $rbutton20 = $frame35->Label(
+                        #-text => "Rsoudre avec\ndes lettres")->pack();
+                        -image => "imagelettres")->pack();
+        }
+        my $balloon20 = $rbutton20->Balloon();
+        $balloon20->attach($rbutton20, -msg => tr1("Il y a des lettres\n dans les cases"));
+        #my $Label6 = $frame35->Label(-text => ' ', -background => $couleurfond,
+         #       -height => 4, -width => 10)->pack;
         my $Label6 = $frame35->Label(-text => ' ', -background => $couleurfond,
                 -height => 4, -width => 10)->pack;
         $frame35->Photo('imageen', -file => $pref . '/photos/button/en/drapeau.gif');
         if ($langue ne "en") {
-                $rbutton20 = $frame35->Button(-command => [\&changelang,"en"],
+                $rbutton22 = $frame35->Button(-command => [\&changelang,"en"],
                         -background => $couleurfond,
                         #-text => "English")->pack();
                         -image => "imageen")->pack(); 
         } else {
-                $rbutton20 = $frame35->Label(
+                $rbutton22 = $frame35->Label(
                         #-text => "English")->pack();
                         -background => $couleurfond,
                         -image => "imageen")->pack(); 
         } 
-        my $balloon20 = $rbutton20->Balloon();
-        $balloon20->attach($rbutton20, -msg => tr1("anglais"));
+        my $balloon22 = $rbutton22->Balloon();
+        $balloon22->attach($rbutton22, -msg => tr1("anglais"));
         $frame35->Photo('imagesp', -file => $pref . '/photos/button/sp/drapeau.gif');
         if ($langue ne "sp") {
-                $rbutton21 = $frame35->Button(-command => [\&changelang,"sp"],
+                $rbutton23 = $frame35->Button(-command => [\&changelang,"sp"],
                         -background => $couleurfond,
                         -image => "imagesp")->pack(); 
         } else {
-                $rbutton21 = $frame35->Label(
+                $rbutton23 = $frame35->Label(
                         -background => $couleurfond,
                         -image => "imagesp")->pack(); 
         }
-        my $balloon21 = $rbutton21->Balloon();
-        $balloon21->attach($rbutton21, -msg => tr1("espagnol")); 
+        my $balloon23 = $rbutton23->Balloon();
+        $balloon23->attach($rbutton23, -msg => tr1("espagnol")); 
         $frame35->Photo('imagept', -file => $pref . '/photos/button/pt/drapeau.gif');
         if ($langue ne "pt") {
-                $rbutton22 = $frame35->Button(-command => [\&changelang,"pt"],
+                $rbutton24 = $frame35->Button(-command => [\&changelang,"pt"],
                         -background => $couleurfond,
                         -image => "imagept")->pack(); 
         } else {
-                $rbutton22 = $frame35->Label(
+                $rbutton24 = $frame35->Label(
                         -background => $couleurfond,
                         -image => "imagept")->pack(); 
         }
-        my $balloon22 = $rbutton22->Balloon();
-        $balloon22->attach($rbutton22, -msg => tr1("portugais"));
+        my $balloon24 = $rbutton24->Balloon();
+        $balloon24->attach($rbutton24, -msg => tr1("portugais"));
 } else {                                # normal look              
         $canvas = $main->Label(-text => 'Sudoku',
                -height => 4, -width => 10,
