@@ -69,6 +69,7 @@ sub traduction {                # translation
                 "en", "Erreur", "Error",
                 "en", "Tout n\'est pas trouv", "Solution is not complete",
                 "en", "Saisir chiffres", "Type numbers",
+                "en", "Saisir lettres", "Type letters",
                 "en", "Faux la bonne valeur est ","False the right value is ",
                 "en", "Bravo", "Cheer!",
                 "en", "Tout est rgl", "Enturely resolved",
@@ -95,7 +96,11 @@ sub traduction {                # translation
                 "en", "Enfant","Child",
                 "en", "chiffres","numbers",
                 "en", "animaux","animals",
+                "en", "lettres","letters",
+                "en", "couleurs","colors",
+                "en", "Choisissez", "Choose",
                 "en", "Choisir dessin","Choose drawings",
+                "en", "Choisir couleurs", "Choose colors",
                 "en", "Annulation","Cancellation",
                 "en", "Simpliste","Simplistic",
                 "en", "Ardu","Arduous",
@@ -109,6 +114,8 @@ sub traduction {                # translation
                 "en", "Saisir une grille\npour la rsoudre", "To seize a grid\nto solve it",
                 "en", "Crer une grille soi mme", "Create a grid oneself",
                 "en", "Il y a des chiffres\n dans les cases", "There are figures\nin the boxes",
+                "en", "Il y a des lettres\n dans les cases", "There are letters\nin the boxes",
+                "en", "Il y a des couleurs\n dans les cases", "There are colors\nin the boxes",
                 "en", "Demander une nouvelle grille", "Ask for a new grid",
                 "en", "Il y a des animaux\n dans les cases", "There are animals\n in the boxes",
                 "ge", "OUI", "YA",
@@ -121,6 +128,7 @@ sub traduction {                # translation
                 "ge", "Erreur", "Fehler",
                 "ge", "Tout n\'est pas trouv", "Alles wird nicht gefunden",
                 "ge", "Saisir chiffres", "Zahlen erfassen",
+                "ge", "Saisir lettres", "Briefe erfassen",
                 "ge", "Bravo", "Bravo!",
                 "ge", "Tout est rgl", "Alles gefunden wird",
                 "ge", "Faux la bonne valeur est ","Unwahrheit der gute Wert ist ",
@@ -147,7 +155,11 @@ sub traduction {                # translation
                 "ge", "Enfant","Kinder",
                 "ge", "chiffres","Zahlen",
                 "ge", "animaux","Tiere",
+                "ge", "lettres","Briefe",
+                "ge", "couleurs","Farben",
+                "ge", "Choisissez", "Whlen Sie",
                 "ge", "Choisir dessin","Zeichnung whlen",
+                "ge", "Choisir couleurs", "Farben whlen",
                 "ge", "Annulation","Annullierung",
                 "ge", "Simpliste","Einfach",
                 "ge", "Ardu","Schwierig",
@@ -161,6 +173,7 @@ sub traduction {                # translation
                 "ge", "Saisir une grille\npour la rsoudre", "Ein Gitter erfassen,\num es zu lsen",
                 "ge", "Crer une grille soi mme", "Ein Gitter es sogar schaffen",
                 "ge", "Il y a des chiffres\n dans les cases", "Es gibt Zahlen in den Ksten",
+                "ge", "Il y a des lettres\n dans les cases", "Es gibt Briefe\nin den Ksten",
                 "ge", "Demander une nouvelle grille", "ein neues Gitter zu verlangen",
                 "ge", "Il y a des animaux\n dans les cases", "Es gibt Tiere in den Ksten",
                 "sp", "OUI", "SI",
@@ -173,6 +186,7 @@ sub traduction {                # translation
                 "sp", "Erreur", "Error",
                 "sp", "Tout n\'est pas trouv", "No se encuentra todo",
                 "sp", "Saisir chiffres", "Coger cifras",
+                "sp", "Saisir lettres", "Coger cartas",
                 "sp", "Bravo", "Bravo!",
                 "sp", "Tout est rgl", "Todo se encuentra",
                 "sp", "Faux la bonne valeur est ","Falsificacin el buen valor es ",
@@ -199,7 +213,11 @@ sub traduction {                # translation
                 "sp", "Enfant","Nio",
                 "sp", "chiffres","cifras",
                 "sp", "animaux","animales",
+                "sp", "lettres","letras",
+                "sp", "couleurs","colores",
+                "sp", "Choisissez", "Escoja",
                 "sp", "Choisir dessin","Escoger dibujo",
+                "en", "Choisir couleurs", "Escoger colores",
                 "sp", "Annulation","Anulacin",
                 "sp", "Simpliste","Simplista",
                 "sp", "Ardu","Arduo",
@@ -213,6 +231,8 @@ sub traduction {                # translation
                 "sp", "Saisir une grille\npour la rsoudre", "Coger una rejilla\npara solucionarlo",
                 "sp", "Crer une grille soi mme", "Crear una rejilla s incluso",
                 "sp", "Il y a des chiffres\n dans les cases", "Hay cifras\nen las casillas",
+                "sp", "Il y a des lettres\n dans les cases", "Hay letras\nen las casillas",
+                "sp", "Il y a des couleurs\n dans les cases", "Hay colores\nen las casillas",
                 "sp", "Demander une nouvelle grille", "pedir una nueva rejilla",
                 "sp", "Il y a des animaux\n dans les cases", "Hay animales\n en las casillas",
                 "it", "OUI", "SI",
@@ -225,6 +245,7 @@ sub traduction {                # translation
                 "it", "Erreur", "Errore",
                 "it", "Tout n\'est pas trouv", "Tutto non  trovato",
                 "it", "Saisir chiffres", "Osservare cifre",
+                "it", "Saisir lettres", "Osservare lettere",
                 "it", "Bravo", "Bravo!",
                 "it", "Tout est rgl", "Tutto  trovato",
                 "it", "Faux la bonne valeur est ","Falsificazione il buon valore  ",
@@ -251,7 +272,11 @@ sub traduction {                # translation
                 "it", "Enfant","Bambino",
                 "it", "chiffres","numeri",
                 "it", "animaux","animali",
+                "it", "lettres","lettere",
+                "it", "couleurs","colori",
+                "it", "Choisissez", "Scegliete",
                 "it", "Choisir dessin","Scegliere disegno",
+                "it", "Choisir couleurs", "Scegliere colori",
                 "it", "Annulation","Annullamento",
                 "it", "Simpliste","Simplista",
                 "it", "Ardu","Arduo",
@@ -265,8 +290,10 @@ sub traduction {                # translation
                 "it", "Saisir une grille\npour la rsoudre", "Afferrare una griglia\nper risolverla",
                 "it", "Crer une grille soi mme", "Creare una griglia s anche",
                 "it", "Il y a des chiffres\n dans les cases", "Ci sono cifre\nnelle scatole",
+                "it", "Il y a des lettres\n dans les cases", "Ci sono lettere\nnelle scatole",
                 "it", "Demander une nouvelle grille", "chiedere una nuova griglia",
                 "it", "Il y a des animaux\n dans les cases", "Ci sono animali\n nelle scatole",
+                "it", "Il y a des couleurs\n dans les cases", "Ci sono colori\n nelle scatole",
                 "pt", "OUI", "SIM",
                 "pt", "NON", "NAO",
                 "pt", "FIN SAISIE", "FIM DE APREENSAO",
@@ -278,6 +305,7 @@ sub traduction {                # translation
                 "pt", "Tout n\'est pas trouv", "Todo no  encontrado",
                 "pt", "Faux la bonne valeur est ","Falsificao o valor bom  ",
                 "pt", "Saisir chiffres", "Apreender numeros",
+                "pt", "Saisir lettres", "Apreender cartas",
                 "pt", "Bravo", "Bravo!",
                 "pt", "Tout est rgl", "Qualquer  encontrado",
                 "pt", "Fichier", "Fichero",
@@ -302,7 +330,11 @@ sub traduction {                # translation
                 "pt", "Aide?","ayuda?",
                 "pt", "chiffres","nmeros",
                 "pt", "animaux","animais",
+                "pt", "lettres","lettere",
+                "pt", "couleurs","cores",
+                "pt", "Choisissez", "Selecionar",
                 "pt", "Choisir dessin","Escolher desenho",
+                "pt", "Choisir couleurs", "Escolher cores",
                 "pt", "Annulation","Anulao",
                 "pt", "Enfant","criana",
                 "pt", "Simpliste","Simplista",
@@ -318,6 +350,8 @@ sub traduction {                # translation
                 "pt", "Il y a des chiffres\n dans les cases", "H nmeros\nnos compartimentos",
                 "pt", "Demander une nouvelle grille", "pedir uma nova grelha",
                 "pt", "Il y a des animaux\n dans les cases", "H animais\nnos compartimentos",
+                "pt", "Il y a des lettres\n dans les cases", "H cartas\nnos compartimentos",
+                "pt", "Il y a des couleurs\n dans les cases", "H cores\nnos compartimentos",
                 "pt", "Ardu","rduo"
                 );
         my ($langue,$nomfr) = @_;
